"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
require("!style-loader!css-loader!../../styles/osteo.css");
var _osteoRadioButton = _interopRequireDefault(require("./osteoRadioButton"));
var _osteoCheckbox = _interopRequireDefault(require("./osteoCheckbox"));
var _constants = require("../constants");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/* global window */

// eslint-disable-next-line import/no-webpack-loader-syntax, import/no-unresolved

const relations = {
  Cranium: {
    children: ['Frontal_L', 'Frontal_R', 'Occipital', 'Sphenoid', 'Vomer', 'Ethmoid', 'Parietal_L', 'Parietal_R', 'Temporal_L', 'Temporal_R', 'Maxilla_L', 'Maxilla_R', 'Nasal_L', 'Nasal_R', 'Zygomatic_L', 'Zygomatic_R', 'Lacrimal_L', 'Lacrimal_R', 'Palatine_L', 'Palatine_R', 'Mandible_L', 'Mandible_R', 'Orbit_L', 'Orbit_R'],
    computedFrom: ['Frontal_L', 'Frontal_R', 'Occipital', 'Sphenoid', 'Vomer', 'Ethmoid', 'Parietal_L', 'Parietal_R', 'Temporal_L', 'Temporal_R', 'Maxilla_L', 'Maxilla_R', 'Nasal_L', 'Nasal_R', 'Zygomatic_L', 'Zygomatic_R', 'Lacrimal_L', 'Lacrimal_R', 'Palatine_L', 'Palatine_R', 'Mandible_L', 'Mandible_R', 'Orbit_L', 'Orbit_R']
  },
  Occipital: {
    children: ['Occipital_pars_basilaris', 'Occipital_L_pars_lateralis', 'Occipital_R_pars_lateralis'],
    computedFrom: ['Occipital_pars_basilaris', 'Occipital_L_pars_lateralis', 'Occipital_R_pars_lateralis', '__other__']
  },
  //

  Humerus_L_complete: {
    children: ['Humerus_L_JS_P', 'Humerus_L_shaft_P', 'Humerus_L_shaft_M', 'Humerus_L_shaft_D', 'Humerus_L_JS_D'],
    computedFrom: ['Humerus_L_JS_P', 'Humerus_L_shaft_P', 'Humerus_L_shaft_M', 'Humerus_L_shaft_D', 'Humerus_L_JS_D']
  },
  Humerus_R_complete: {
    children: ['Humerus_R_JS_P', 'Humerus_R_shaft_P', 'Humerus_R_shaft_M', 'Humerus_R_shaft_D', 'Humerus_R_JS_D'],
    computedFrom: ['Humerus_R_JS_P', 'Humerus_R_shaft_P', 'Humerus_R_shaft_M', 'Humerus_R_shaft_D', 'Humerus_R_JS_D']
  },
  Radius_L_complete: {
    children: ['Radius_L_JS_P', 'Radius_L_shaft_P', 'Radius_L_shaft_M', 'Radius_L_shaft_D', 'Radius_L_JS_D'],
    computedFrom: ['Radius_L_JS_P', 'Radius_L_shaft_P', 'Radius_L_shaft_M', 'Radius_L_shaft_D', 'Radius_L_JS_D']
  },
  Radius_R_complete: {
    children: ['Radius_R_JS_P', 'Radius_R_shaft_P', 'Radius_R_shaft_M', 'Radius_R_shaft_D', 'Radius_R_JS_D'],
    computedFrom: ['Radius_R_JS_P', 'Radius_R_shaft_P', 'Radius_R_shaft_M', 'Radius_R_shaft_D', 'Radius_R_JS_D']
  },
  Ulna_L_complete: {
    children: ['Ulna_L_JS_P', 'Ulna_L_shaft_P', 'Ulna_L_shaft_M', 'Ulna_L_shaft_D', 'Ulna_L_JS_D'],
    computedFrom: ['Ulna_L_JS_P', 'Ulna_L_shaft_P', 'Ulna_L_shaft_M', 'Ulna_L_shaft_D', 'Ulna_L_JS_D']
  },
  Ulna_R_complete: {
    children: ['Ulna_R_JS_P', 'Ulna_R_shaft_P', 'Ulna_R_shaft_M', 'Ulna_R_shaft_D', 'Ulna_R_JS_D'],
    computedFrom: ['Ulna_R_JS_P', 'Ulna_R_shaft_P', 'Ulna_R_shaft_M', 'Ulna_R_shaft_D', 'Ulna_R_JS_D']
  },
  //

  Femur_L_complete: {
    children: ['Femur_L_JS_P', 'Femur_L_shaft_P', 'Femur_L_shaft_M', 'Femur_L_shaft_D', 'Femur_L_JS_D'],
    computedFrom: ['Femur_L_JS_P', 'Femur_L_shaft_P', 'Femur_L_shaft_M', 'Femur_L_shaft_D', 'Femur_L_JS_D']
  },
  Femur_R_complete: {
    children: ['Femur_R_JS_P', 'Femur_R_shaft_P', 'Femur_R_shaft_M', 'Femur_R_shaft_D', 'Femur_R_JS_D'],
    computedFrom: ['Femur_R_JS_P', 'Femur_R_shaft_P', 'Femur_R_shaft_M', 'Femur_R_shaft_D', 'Femur_R_JS_D']
  },
  Tibia_L_complete: {
    children: ['Tibia_L_JS_P', 'Tibia_L_shaft_P', 'Tibia_L_shaft_M', 'Tibia_L_shaft_D', 'Tibia_L_JS_D'],
    computedFrom: ['Tibia_L_JS_P', 'Tibia_L_shaft_P', 'Tibia_L_shaft_M', 'Tibia_L_shaft_D', 'Tibia_L_JS_D']
  },
  Tibia_R_complete: {
    children: ['Tibia_R_JS_P', 'Tibia_R_shaft_P', 'Tibia_R_shaft_M', 'Tibia_R_shaft_D', 'Tibia_R_JS_D'],
    computedFrom: ['Tibia_R_JS_P', 'Tibia_R_shaft_P', 'Tibia_R_shaft_M', 'Tibia_R_shaft_D', 'Tibia_R_JS_D']
  },
  Fibula_L_complete: {
    children: ['Fibula_L_JS_P', 'Fibula_L_shaft_P', 'Fibula_L_shaft_M', 'Fibula_L_shaft_D', 'Fibula_L_JS_D'],
    computedFrom: ['Fibula_L_JS_P', 'Fibula_L_shaft_P', 'Fibula_L_shaft_M', 'Fibula_L_shaft_D', 'Fibula_L_JS_D']
  },
  Fibula_R_complete: {
    children: ['Fibula_R_JS_P', 'Fibula_R_shaft_P', 'Fibula_R_shaft_M', 'Fibula_R_shaft_D', 'Fibula_R_JS_D'],
    computedFrom: ['Fibula_R_JS_P', 'Fibula_R_shaft_P', 'Fibula_R_shaft_M', 'Fibula_R_shaft_D', 'Fibula_R_JS_D']
  },
  //

  Os_coxae_L: {
    children: ['Ischium_L', 'Ilium_L', 'Pubis_L', 'Acetabulum_L', 'Auricular_surf_L'],
    computedFrom: ['Ischium_L', 'Ilium_L', 'Pubis_L']
  },
  Ischium_L: {
    markVisited: ['Acetabulum_L', 'Auricular_surf_L']
  },
  Ilium_L: {
    markVisited: ['Acetabulum_L', 'Auricular_surf_L']
  },
  Acetabulum_L: {
    markVisited: ['Auricular_surf_L']
  },
  Auricular_surf_L: {
    markVisited: ['Acetabulum_L']
  },
  Pubis_L: {
    markVisited: ['Acetabulum_L', 'Auricular_surf_L']
  },
  Os_coxae_R: {
    children: ['Ischium_R', 'Ilium_R', 'Pubis_R', 'Acetabulum_R', 'Auricular_surf_R'],
    computedFrom: ['Ischium_R', 'Ilium_R', 'Pubis_R']
  },
  Ischium_R: {
    markVisited: ['Acetabulum_R', 'Auricular_surf_R']
  },
  Ilium_R: {
    markVisited: ['Acetabulum_R', 'Auricular_surf_R']
  },
  Pubis_R: {
    markVisited: ['Acetabulum_R', 'Auricular_surf_R']
  },
  Scapula_L: {
    children: ['Glenoid_L'],
    computedFrom: ['Glenoid_L', '__other__']
  },
  Scapula_R: {
    children: ['Glenoid_R'],
    computedFrom: ['Glenoid_R', '__other__']
  },
  Sternum: {
    children: ['Manubrium'],
    computedFrom: ['Manubrium', '__other__']
  },
  //

  Carpals_L_complete: {
    children: ['Scaphoid_L', 'Lunate_L', 'Triquetral_L', 'Pisiform_L', 'Trapezium_L', 'Trapezoid_L', 'Capitate_L', 'Hamate_L'],
    computedFrom: ['Scaphoid_L', 'Lunate_L', 'Triquetral_L', 'Pisiform_L', 'Trapezium_L', 'Trapezoid_L', 'Capitate_L', 'Hamate_L']
  },
  Carpals_R_complete: {
    children: ['Scaphoid_R', 'Lunate_R', 'Triquetral_R', 'Pisiform_R', 'Trapezium_R', 'Trapezoid_R', 'Capitate_R', 'Hamate_R'],
    computedFrom: ['Scaphoid_R', 'Lunate_R', 'Triquetral_R', 'Pisiform_R', 'Trapezium_R', 'Trapezoid_R', 'Capitate_R', 'Hamate_R']
  },
  //

  Tarsals_L_complete: {
    children: ['Talus_L', 'Calcaneus_L', 'Navicular_L', 'Cuboid_L', 'Med_cuneif_1_L', 'Int_cuneif_2_L', 'Lat_cuneif_3_L'],
    computedFrom: ['Talus_L', 'Calcaneus_L', 'Navicular_L', 'Cuboid_L', 'Med_cuneif_1_L', 'Int_cuneif_2_L', 'Lat_cuneif_3_L']
  },
  Tarsals_R_complete: {
    children: ['Talus_R', 'Calcaneus_R', 'Navicular_R', 'Cuboid_R', 'Med_cuneif_1_R', 'Int_cuneif_2_R', 'Lat_cuneif_3_R'],
    computedFrom: ['Talus_R', 'Calcaneus_R', 'Navicular_R', 'Cuboid_R', 'Med_cuneif_1_R', 'Int_cuneif_2_R', 'Lat_cuneif_3_R']
  },
  //

  MC_L_complete: {
    children: ['MC1_L', 'MC2_L', 'MC3_L', 'MC4_L', 'MC5_L'],
    computedFrom: ['MC1_L', 'MC2_L', 'MC3_L', 'MC4_L', 'MC5_L']
  },
  MC_R_complete: {
    children: ['MC1_R', 'MC2_R', 'MC3_R', 'MC4_R', 'MC5_R'],
    computedFrom: ['MC1_R', 'MC2_R', 'MC3_R', 'MC4_R', 'MC5_R']
  },
  //

  MT_L_complete: {
    children: ['MT1_L', 'MT2_L', 'MT3_L', 'MT4_L', 'MT5_L'],
    computedFrom: ['MT1_L', 'MT2_L', 'MT3_L', 'MT4_L', 'MT5_L']
  },
  MT_R_complete: {
    children: ['MT1_R', 'MT2_R', 'MT3_R', 'MT4_R', 'MT5_R'],
    computedFrom: ['MT1_R', 'MT2_R', 'MT3_R', 'MT4_R', 'MT5_R']
  },
  //

  Ribs_L_complete: {
    children: ['Rib1_L', 'Rib2_L', 'Rib3_L', 'Rib4_L', 'Rib5_L', 'Rib6_L', 'Rib7_L', 'Rib8_L', 'Rib9_L', 'Rib10_L', 'Rib11_L', 'Rib12_L'],
    computedFrom: ['Rib1_L', 'Rib2_L', 'Rib3_L', 'Rib4_L', 'Rib5_L', 'Rib6_L', 'Rib7_L', 'Rib8_L', 'Rib9_L', 'Rib10_L', 'Rib11_L', 'Rib12_L']
  },
  Rib1_L: {
    children: ['Rib1_L_sternal_end_complete', 'Rib1_L_head_neck_complete'],
    computedFrom: ['Rib1_L_sternal_end_complete', 'Rib1_L_head_neck_complete', '__other__']
  },
  Rib2_L: {
    children: ['Rib2_L_sternal_end_complete', 'Rib2_L_head_neck_complete'],
    computedFrom: ['Rib2_L_sternal_end_complete', 'Rib2_L_head_neck_complete', '__other__']
  },
  Rib3_L: {
    children: ['Rib3_L_sternal_end_complete', 'Rib3_L_head_neck_complete'],
    computedFrom: ['Rib3_L_sternal_end_complete', 'Rib3_L_head_neck_complete', '__other__']
  },
  Rib4_L: {
    children: ['Rib4_L_sternal_end_complete', 'Rib4_L_head_neck_complete'],
    computedFrom: ['Rib4_L_sternal_end_complete', 'Rib4_L_head_neck_complete', '__other__']
  },
  Rib5_L: {
    children: ['Rib5_L_sternal_end_complete', 'Rib5_L_head_neck_complete'],
    computedFrom: ['Rib5_L_sternal_end_complete', 'Rib5_L_head_neck_complete', '__other__']
  },
  Rib6_L: {
    children: ['Rib6_L_sternal_end_complete', 'Rib6_L_head_neck_complete'],
    computedFrom: ['Rib6_L_sternal_end_complete', 'Rib6_L_head_neck_complete', '__other__']
  },
  Rib7_L: {
    children: ['Rib7_L_sternal_end_complete', 'Rib7_L_head_neck_complete'],
    computedFrom: ['Rib7_L_sternal_end_complete', 'Rib7_L_head_neck_complete', '__other__']
  },
  Rib8_L: {
    children: ['Rib8_L_sternal_end_complete', 'Rib8_L_head_neck_complete'],
    computedFrom: ['Rib8_L_sternal_end_complete', 'Rib8_L_head_neck_complete', '__other__']
  },
  Rib9_L: {
    children: ['Rib9_L_sternal_end_complete', 'Rib9_L_head_neck_complete'],
    computedFrom: ['Rib9_L_sternal_end_complete', 'Rib9_L_head_neck_complete', '__other__']
  },
  Rib10_L: {
    children: ['Rib10_L_sternal_end_complete', 'Rib10_L_head_neck_complete'],
    computedFrom: ['Rib10_L_sternal_end_complete', 'Rib10_L_head_neck_complete', '__other__']
  },
  Rib11_L: {
    children: ['Rib11_L_sternal_end_complete', 'Rib11_L_head_neck_complete'],
    computedFrom: ['Rib11_L_sternal_end_complete', 'Rib11_L_head_neck_complete', '__other__']
  },
  Rib12_L: {
    children: ['Rib12_L_sternal_end_complete', 'Rib12_L_head_neck_complete'],
    computedFrom: ['Rib12_L_sternal_end_complete', 'Rib12_L_head_neck_complete', '__other__']
  },
  Ribs_R_complete: {
    children: ['Rib1_R', 'Rib2_R', 'Rib3_R', 'Rib4_R', 'Rib5_R', 'Rib6_R', 'Rib7_R', 'Rib8_R', 'Rib9_R', 'Rib10_R', 'Rib11_R', 'Rib12_R'],
    computedFrom: ['Rib1_R', 'Rib2_R', 'Rib3_R', 'Rib4_R', 'Rib5_R', 'Rib6_R', 'Rib7_R', 'Rib8_R', 'Rib9_R', 'Rib10_R', 'Rib11_R', 'Rib12_R']
  },
  Rib1_R: {
    children: ['Rib1_R_sternal_end_complete', 'Rib1_R_head_neck_complete'],
    computedFrom: ['Rib1_R_sternal_end_complete', 'Rib1_R_head_neck_complete', '__other__']
  },
  Rib2_R: {
    children: ['Rib2_R_sternal_end_complete', 'Rib2_R_head_neck_complete'],
    computedFrom: ['Rib2_R_sternal_end_complete', 'Rib2_R_head_neck_complete', '__other__']
  },
  Rib3_R: {
    children: ['Rib3_R_sternal_end_complete', 'Rib3_R_head_neck_complete'],
    computedFrom: ['Rib3_R_sternal_end_complete', 'Rib3_R_head_neck_complete', '__other__']
  },
  Rib4_R: {
    children: ['Rib4_R_sternal_end_complete', 'Rib4_R_head_neck_complete'],
    computedFrom: ['Rib4_R_sternal_end_complete', 'Rib4_R_head_neck_complete', '__other__']
  },
  Rib5_R: {
    children: ['Rib5_R_sternal_end_complete', 'Rib5_R_head_neck_complete'],
    computedFrom: ['Rib5_R_sternal_end_complete', 'Rib5_R_head_neck_complete', '__other__']
  },
  Rib6_R: {
    children: ['Rib6_R_sternal_end_complete', 'Rib6_R_head_neck_complete'],
    computedFrom: ['Rib6_R_sternal_end_complete', 'Rib6_R_head_neck_complete', '__other__']
  },
  Rib7_R: {
    children: ['Rib7_R_sternal_end_complete', 'Rib7_R_head_neck_complete'],
    computedFrom: ['Rib7_R_sternal_end_complete', 'Rib7_R_head_neck_complete', '__other__']
  },
  Rib8_R: {
    children: ['Rib8_R_sternal_end_complete', 'Rib8_R_head_neck_complete'],
    computedFrom: ['Rib8_R_sternal_end_complete', 'Rib8_R_head_neck_complete', '__other__']
  },
  Rib9_R: {
    children: ['Rib9_R_sternal_end_complete', 'Rib9_R_head_neck_complete'],
    computedFrom: ['Rib9_R_sternal_end_complete', 'Rib9_R_head_neck_complete', '__other__']
  },
  Rib10_R: {
    children: ['Rib10_R_sternal_end_complete', 'Rib10_R_head_neck_complete'],
    computedFrom: ['Rib10_R_sternal_end_complete', 'Rib10_R_head_neck_complete', '__other__']
  },
  Rib11_R: {
    children: ['Rib11_R_sternal_end_complete', 'Rib11_R_head_neck_complete'],
    computedFrom: ['Rib11_R_sternal_end_complete', 'Rib11_R_head_neck_complete', '__other__']
  },
  Rib12_R: {
    children: ['Rib12_R_sternal_end_complete', 'Rib12_R_head_neck_complete'],
    computedFrom: ['Rib12_R_sternal_end_complete', 'Rib12_R_head_neck_complete', '__other__']
  },
  //

  Vertebrae_complete: {
    children: ['C1_complete', 'C2_complete', 'C3_complete', 'C4_complete', 'C5_complete', 'C6_complete', 'C7_complete', 'T1_complete', 'T2_complete', 'T3_complete', 'T4_complete', 'T5_complete', 'T6_complete', 'T7_complete', 'T8_complete', 'T9_complete', 'T10_complete', 'T11_complete', 'T12_complete', 'L1_complete', 'L2_complete', 'L3_complete', 'L4_complete', 'L5_complete', 'Sacrum_complete', 'Coccyx_complete'],
    computedFrom: ['C1_complete', 'C2_complete', 'C3_complete', 'C4_complete', 'C5_complete', 'C6_complete', 'C7_complete', 'T1_complete', 'T2_complete', 'T3_complete', 'T4_complete', 'T5_complete', 'T6_complete', 'T7_complete', 'T8_complete', 'T9_complete', 'T10_complete', 'T11_complete', 'T12_complete', 'L1_complete', 'L2_complete', 'L3_complete', 'L4_complete', 'L5_complete', 'Sacrum_complete', 'Coccyx_complete']
  },
  C1_complete: {
    children: ['C1_L_arch', 'C1_R_arch'],
    computedFrom: ['C1_L_arch', 'C1_R_arch', '__other__']
  },
  C2_complete: {
    children: ['C2_centrum', 'C2_L_arch', 'C2_R_arch'],
    computedFrom: ['C2_centrum', 'C2_L_arch', 'C2_R_arch', '__other__']
  },
  C3_complete: {
    children: ['C3_centrum', 'C3_L_arch', 'C3_R_arch'],
    computedFrom: ['C3_centrum', 'C3_L_arch', 'C3_R_arch', '__other__']
  },
  C4_complete: {
    children: ['C4_centrum', 'C4_L_arch', 'C4_R_arch'],
    computedFrom: ['C4_centrum', 'C4_L_arch', 'C4_R_arch', '__other__']
  },
  C5_complete: {
    children: ['C5_centrum', 'C5_L_arch', 'C5_R_arch'],
    computedFrom: ['C5_centrum', 'C5_L_arch', 'C5_R_arch', '__other__']
  },
  C6_complete: {
    children: ['C6_centrum', 'C6_L_arch', 'C6_R_arch'],
    computedFrom: ['C6_centrum', 'C6_L_arch', 'C6_R_arch', '__other__']
  },
  C7_complete: {
    children: ['C7_centrum', 'C7_L_arch', 'C7_R_arch'],
    computedFrom: ['C7_centrum', 'C7_L_arch', 'C7_R_arch', '__other__']
  },
  T1_complete: {
    children: ['T1_centrum', 'T1_L_arch', 'T1_R_arch'],
    computedFrom: ['T1_centrum', 'T1_L_arch', 'T1_R_arch', '__other__']
  },
  T2_complete: {
    children: ['T2_centrum', 'T2_L_arch', 'T2_R_arch'],
    computedFrom: ['T2_centrum', 'T2_L_arch', 'T2_R_arch', '__other__']
  },
  T3_complete: {
    children: ['T3_centrum', 'T3_L_arch', 'T3_R_arch'],
    computedFrom: ['T3_centrum', 'T3_L_arch', 'T3_R_arch', '__other__']
  },
  T4_complete: {
    children: ['T4_centrum', 'T4_L_arch', 'T4_R_arch'],
    computedFrom: ['T4_centrum', 'T4_L_arch', 'T4_R_arch', '__other__']
  },
  T5_complete: {
    children: ['T5_centrum', 'T5_L_arch', 'T5_R_arch'],
    computedFrom: ['T5_centrum', 'T5_L_arch', 'T5_R_arch', '__other__']
  },
  T6_complete: {
    children: ['T6_centrum', 'T6_L_arch', 'T6_R_arch'],
    computedFrom: ['T6_centrum', 'T6_L_arch', 'T6_R_arch', '__other__']
  },
  T7_complete: {
    children: ['T7_centrum', 'T7_L_arch', 'T7_R_arch'],
    computedFrom: ['T7_centrum', 'T7_L_arch', 'T7_R_arch', '__other__']
  },
  T8_complete: {
    children: ['T8_centrum', 'T8_L_arch', 'T8_R_arch'],
    computedFrom: ['T8_centrum', 'T8_L_arch', 'T8_R_arch', '__other__']
  },
  T9_complete: {
    children: ['T9_centrum', 'T9_L_arch', 'T9_R_arch'],
    computedFrom: ['T9_centrum', 'T9_L_arch', 'T9_R_arch', '__other__']
  },
  T10_complete: {
    children: ['T10_centrum', 'T10_L_arch', 'T10_R_arch'],
    computedFrom: ['T10_centrum', 'T10_L_arch', 'T10_R_arch', '__other__']
  },
  T11_complete: {
    children: ['T11_centrum', 'T11_L_arch', 'T11_R_arch'],
    computedFrom: ['T11_centrum', 'T11_L_arch', 'T11_R_arch', '__other__']
  },
  T12_complete: {
    children: ['T12_centrum', 'T12_L_arch', 'T12_R_arch'],
    computedFrom: ['T12_centrum', 'T12_L_arch', 'T12_R_arch', '__other__']
  },
  L1_complete: {
    children: ['L1_centrum', 'L1_L_arch', 'L1_R_arch'],
    computedFrom: ['L1_centrum', 'L1_L_arch', 'L1_R_arch', '__other__']
  },
  L2_complete: {
    children: ['L2_centrum', 'L2_L_arch', 'L2_R_arch'],
    computedFrom: ['L2_centrum', 'L2_L_arch', 'L2_R_arch', '__other__']
  },
  L3_complete: {
    children: ['L3_centrum', 'L3_L_arch', 'L3_R_arch'],
    computedFrom: ['L3_centrum', 'L3_L_arch', 'L3_R_arch', '__other__']
  },
  L4_complete: {
    children: ['L4_centrum', 'L4_L_arch', 'L4_R_arch'],
    computedFrom: ['L4_centrum', 'L4_L_arch', 'L4_R_arch', '__other__']
  },
  L5_complete: {
    children: ['L5_centrum', 'L5_L_arch', 'L5_R_arch'],
    computedFrom: ['L5_centrum', 'L5_L_arch', 'L5_R_arch', '__other__']
  },
  Sacrum_complete: {
    children: ['Sacrum', 'Sacrum_L_alae', 'Sacrum_R_alae', 'S1_complete', 'S2_complete', 'S3_complete', 'S4_complete', 'S5_complete'],
    computedFrom: ['S1_complete', 'S2_complete', 'S3_complete', 'S4_complete', 'S5_complete']
  },
  Sacrum: {
    children: ['S1_centrum', 'S2_centrum', 'S3_centrum', 'S4_centrum', 'S5_centrum'],
    computedFrom: ['S1_centrum', 'S2_centrum', 'S3_centrum', 'S4_centrum', 'S5_centrum']
  },
  Sacrum_L_alae: {
    children: ['S1_L_ala', 'S2_L_ala', 'S3_L_ala', 'S4_L_ala', 'S5_L_ala'],
    computedFrom: ['S1_L_ala', 'S2_L_ala', 'S3_L_ala', 'S4_L_ala', 'S5_L_ala']
  },
  Sacrum_R_alae: {
    children: ['S1_R_ala', 'S2_R_ala', 'S3_R_ala', 'S4_R_ala', 'S5_R_ala'],
    computedFrom: ['S1_R_ala', 'S2_R_ala', 'S3_R_ala', 'S4_R_ala', 'S5_R_ala']
  },
  S1_complete: {
    children: ['S1_centrum', 'S1_L_ala', 'S1_R_ala'],
    computedFrom: ['S1_centrum', 'S1_L_ala', 'S1_R_ala', '__other__']
  },
  S2_complete: {
    children: ['S2_centrum', 'S2_L_ala', 'S2_R_ala'],
    computedFrom: ['S2_centrum', 'S2_L_ala', 'S2_R_ala', '__other__']
  },
  S3_complete: {
    children: ['S3_centrum', 'S3_L_ala', 'S3_R_ala'],
    computedFrom: ['S3_centrum', 'S3_L_ala', 'S3_R_ala', '__other__']
  },
  S4_complete: {
    children: ['S4_centrum', 'S4_L_ala', 'S4_R_ala'],
    computedFrom: ['S4_centrum', 'S4_L_ala', 'S4_R_ala', '__other__']
  },
  S5_complete: {
    children: ['S5_centrum', 'S5_L_ala', 'S5_R_ala'],
    computedFrom: ['S5_centrum', 'S5_L_ala', 'S5_R_ala', '__other__']
  },
  Coccyx_complete: {
    children: ['Coccyx'],
    computedFrom: ['Coccyx']
  }
};
const parents = {};
Object.keys(relations).forEach(parentName => {
  const {
    children
  } = relations[parentName];
  if (children) {
    children.forEach(childName => {
      if (!parents[childName]) {
        parents[childName] = [];
      }
      parents[childName].push(parentName);
    });
  }
});
const allFieldsHaveValue = (data, names, value) => names.every(name => data.get(name) === value);
const computeValue = (data, name) => {
  let value = data.get(name);
  if (name in relations) {
    const computedFromFields = relations[name].computedFrom;
    if (computedFromFields && computedFromFields.length > 0) {
      if (allFieldsHaveValue(data, computedFromFields, _constants.COMPLETE_VALUE)) {
        value = _constants.COMPLETE_VALUE;
      } else if (allFieldsHaveValue(data, computedFromFields, _constants.ABSENT_VALUE)) {
        value = _constants.ABSENT_VALUE;
      } else if (value === _constants.COMPLETE_VALUE || value === _constants.ABSENT_VALUE) {
        value = null;
      }
    }
  }
  return value;
};

// TODO: Move strings into messages.
var _default = configContext => {
  const {
    Immutable,
    React,
    Component,
    PropTypes
  } = configContext.lib;
  const {
    pathPropType,
    getPath
  } = configContext.pathHelpers;
  const {
    Button
  } = configContext.inputComponents;
  const Radio = (0, _osteoRadioButton.default)(configContext);
  const Checkbox = (0, _osteoCheckbox.default)(configContext);
  const propTypes = {
    /* eslint-disable react/no-unused-prop-types */
    name: PropTypes.string,
    parentPath: pathPropType,
    subpath: pathPropType,
    children: PropTypes.node,
    /* eslint-enable react/no-unused-prop-types */
    value: PropTypes.instanceOf(Immutable.Map),
    readOnly: PropTypes.bool,
    onCommit: PropTypes.func
  };
  class OsteoInventoryInput extends Component {
    constructor() {
      super();
      this.handleChange = this.handleChange.bind(this);
      this.handleMarkAllAbsentButtonClick = this.handleMarkAllAbsentButtonClick.bind(this);
      this.handleMarkAllPresentButtonClick = this.handleMarkAllPresentButtonClick.bind(this);
      this.handleDeciduousDentZeroButtonClick = this.handleDeciduousDentZeroButtonClick.bind(this);
      this.handlePermanentDentZeroButtonClick = this.handlePermanentDentZeroButtonClick.bind(this);
      this.radioOrCheckboxFieldNames = {};
      this.textFieldNames = {};
    }
    handleChange(event) {
      const {
        nodeName,
        name,
        type,
        value,
        checked
      } = event.target;
      const {
        onCommit,
        value: data
      } = this.props;
      if (nodeName !== 'INPUT' || !onCommit) {
        return;
      }
      let nextValue;
      if (type === 'text' || type === 'radio' && checked) {
        nextValue = value;
      } else if (type === 'checkbox') {
        nextValue = checked ? value : null;
      }
      if (typeof nextValue === 'undefined') {
        return;
      }
      let nextData = data.set(name, nextValue);
      this.visitedFields = {};
      this.visitedFields[name] = true;
      if (name in relations && relations[name].markVisited) {
        relations[name].markVisited.forEach(markVisitedFieldName => {
          this.visitedFields[markVisitedFieldName] = true;
        });
      }
      nextData = this.updateParents(nextData, name);
      if (nextValue === _constants.COMPLETE_VALUE || nextValue === _constants.ABSENT_VALUE || type === 'checkbox') {
        nextData = this.updateChildren(nextData, name, nextValue);
      }
      onCommit(getPath(this.props), nextData);
    }
    handleMarkAllAbsentButtonClick() {
      // eslint-disable-next-line no-alert
      if (window.confirm('Are you sure? This will erase all entered completeness data.')) {
        this.setAllRadioValues(_constants.ABSENT_VALUE);
      }
    }
    handleMarkAllPresentButtonClick() {
      // eslint-disable-next-line no-alert
      if (window.confirm('Are you sure? This will erase all entered completeness data.')) {
        this.setAllRadioValues(_constants.COMPLETE_VALUE);
      }
    }
    handleDeciduousDentZeroButtonClick() {
      this.setAllTextValues(/^Teeth_decid_[UL]/, '0');
    }
    handlePermanentDentZeroButtonClick() {
      this.setAllTextValues(/^Teeth_[UL]/, '0');
    }
    setAllRadioValues(value) {
      const {
        value: data,
        onCommit
      } = this.props;
      if (onCommit) {
        const nextData = data.withMutations(map => {
          Object.keys(this.radioOrCheckboxFieldNames).forEach(name => {
            map.set(name, value);
          });
        });
        onCommit(getPath(this.props), nextData);
      }
    }
    setAllTextValues(namePattern, value) {
      const {
        value: data,
        onCommit
      } = this.props;
      if (onCommit) {
        const nextData = data.withMutations(map => {
          Object.keys(this.textFieldNames).filter(name => namePattern.test(name)).forEach(name => {
            map.set(name, value);
          });
        });
        onCommit(getPath(this.props), nextData);
      }
    }
    updateChildren(data, name, value) {
      let nextData = data;
      if (name in relations) {
        const {
          children
        } = relations[name];
        if (children && children.length > 0) {
          children.forEach(childName => {
            if (!this.visitedFields[childName]) {
              nextData = nextData.set(childName, value);
              this.visitedFields[childName] = true;
              nextData = this.updateChildren(nextData, childName, value);
            }
          });
        }
      }
      return nextData;
    }
    updateParents(data, name) {
      let nextData = data;
      if (name in parents) {
        const parentNames = parents[name];

        // Update parents breadth-first.

        parentNames.forEach(parentName => {
          if (this.visitedFields[parentName]) {
            return;
          }
          const value = computeValue(nextData, parentName);
          nextData = nextData.set(parentName, value);
          this.visitedFields[parentName] = true;
          if (value === _constants.COMPLETE_VALUE || value === _constants.ABSENT_VALUE) {
            nextData = this.updateChildren(nextData, parentName, value);
          }
        });
        parentNames.forEach(parentName => {
          nextData = this.updateParents(nextData, parentName);
        });
      }
      return nextData;
    }
    renderTemplate() {
      const {
        readOnly
      } = this.props;
      let buttonBar;
      let permanentDentZeroButton;
      let deciduousDentZeroButton;
      if (!readOnly) {
        buttonBar = /*#__PURE__*/React.createElement("div", {
          className: "osteo-buttonbar"
        }, /*#__PURE__*/React.createElement(Button, {
          onClick: this.handleMarkAllPresentButtonClick
        }, "Mark all present"), /*#__PURE__*/React.createElement(Button, {
          onClick: this.handleMarkAllAbsentButtonClick
        }, "Mark all absent"));
        permanentDentZeroButton = /*#__PURE__*/React.createElement(Button, {
          className: "zeroButton",
          onClick: this.handlePermanentDentZeroButtonClick
        }, "0");
        deciduousDentZeroButton = /*#__PURE__*/React.createElement(Button, {
          className: "zeroButton",
          onClick: this.handleDeciduousDentZeroButtonClick
        }, "0");
      }

      // FIXME: Properly associate labels with all controls.
      /* eslint-disable
         jsx-a11y/control-has-associated-label,
         jsx-a11y/label-has-associated-control */
      return /*#__PURE__*/React.createElement("div", {
        className: "osteo-form"
      }, buttonBar, /*#__PURE__*/React.createElement("div", {
        className: "osteo-row"
      }, /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", {
        className: "flat-label"
      }, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "5"
      }, "Left/unpaired"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "5"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cranium",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cranium",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cranium",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cranium",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cranium",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cranium",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Cranium")), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Frontal"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Frontal_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Occipital")), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_pars_basilaris",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_pars_basilaris",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_pars_basilaris",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_pars_basilaris",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_pars_basilaris",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_pars_basilaris",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pars basilaris")), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_L_pars_lateralis",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_L_pars_lateralis",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_L_pars_lateralis",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_L_pars_lateralis",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_L_pars_lateralis",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_L_pars_lateralis",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pars lateralis"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_R_pars_lateralis",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_R_pars_lateralis",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_R_pars_lateralis",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_R_pars_lateralis",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_R_pars_lateralis",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Occipital_R_pars_lateralis",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sphenoid",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sphenoid",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sphenoid",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sphenoid",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sphenoid",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sphenoid",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Sphenoid")), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Vomer",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Vomer",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Vomer",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Vomer",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Vomer",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Vomer",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Vomer")), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ethmoid",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ethmoid",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ethmoid",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ethmoid",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ethmoid",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ethmoid",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ethmoid")), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Parietal"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Parietal_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Temporal"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Temporal_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Maxilla"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Maxilla_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Nasal"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Nasal_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Zygomatic"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Zygomatic_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Lacrimal"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lacrimal_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Palatine"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Palatine_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Mandible"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Mandible_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Orbit"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Orbit_R",
        value: "0"
      })))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hyoid",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hyoid",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hyoid",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hyoid",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hyoid",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hyoid",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Hyoid"))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "5"
      }, "Left"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "5"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Humerus"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Prox. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pr. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_M",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Md. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_M",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ds. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_shaft_D",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_L_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Dist. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Humerus_R_JS_D",
        value: "0"
      })))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Radius"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Prox. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pr. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_M",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Md. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_M",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ds. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_shaft_D",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_L_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Dist. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Radius_R_JS_D",
        value: "0"
      })))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Ulna"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Prox. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pr. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_M",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Md. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_M",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ds. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_shaft_D",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_L_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Dist. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ulna_R_JS_D",
        value: "0"
      })))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "5"
      }, "Left"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "5"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Femur"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Prox. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pr. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_M",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Md. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_M",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ds. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_shaft_D",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_L_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Dist. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Femur_R_JS_D",
        value: "0"
      })))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Tibia"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Prox. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pr. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_M",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Md. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_M",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ds. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_shaft_D",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_L_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Dist. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tibia_R_JS_D",
        value: "0"
      })))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Fibula"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Prox. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_P",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pr. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_P",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_P",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_P",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_P",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_P",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_P",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_M",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Md. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_M",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_M",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_M",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_M",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_M",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_M",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ds. 1/3 shaft"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_shaft_D",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_D",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_L_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Dist. JS"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_D",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_D",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_D",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_D",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_D",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Fibula_R_JS_D",
        value: "0"
      }))))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-row"
      }, /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", {
        className: "flat-label"
      }, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "5"
      }, "Left/unpaired"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "5"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Os coxae"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Os_coxae_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ischium"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ischium_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Ilium"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ilium_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pubis"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pubis_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Acetabulum"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Acetabulum_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Auricular sur."), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Auricular_surf_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Scapula"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scapula_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Glenoid"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Glenoid_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Clavicle"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Clavicle_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sternum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sternum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sternum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sternum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sternum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sternum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Sternum")), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Manubrium",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Manubrium",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Manubrium",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Manubrium",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Manubrium",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Manubrium",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Manubrium")), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Patella"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Patella_R",
        value: "0"
      })))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "5"
      }, "Left"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "5"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Carpals_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Carpals_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Wrist"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Carpals_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Carpals_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Scaphoid"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Scaphoid_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Lunate"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lunate_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Triquetral"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Triquetral_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Pisiform"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Pisiform_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Trapezium"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezium_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Trapezoid"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Trapezoid_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Capitate"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Capitate_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Hamate"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Hamate_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", {
        colSpan: "6"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        className: "sesamoid",
        name: "Sesamoid_L_count_hand"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Sesamoid"), /*#__PURE__*/React.createElement("td", {
        colSpan: "6"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        className: "sesamoid",
        name: "Sesamoid_R_count_hand"
      })))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "5"
      }, "Left"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "5"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tarsals_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tarsals_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Ankle"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tarsals_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Tarsals_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Talus"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Talus_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Calcaneus"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Calcaneus_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Navicular"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Navicular_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Cuboid"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Cuboid_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Med. cun. (1)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Med_cuneif_1_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Int. cun. (2)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Int_cuneif_2_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Lat. cun. (3)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Lat_cuneif_3_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", {
        colSpan: "6"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        className: "sesamoid",
        name: "Sesamoid_L_count_foot"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Sesamoid"), /*#__PURE__*/React.createElement("td", {
        colSpan: "6"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        className: "sesamoid",
        name: "Sesamoid_R_count_foot"
      }))))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-row"
      }, /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        colSpan: "4"
      }), /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "3"
      }, "Left"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "3"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "Sternal end")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "Head/neck")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "Head/neck")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "Sternal end")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ribs_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "6"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ribs_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Rib #"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ribs_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "6"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Ribs_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib1_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib1_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "1"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib1_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib1_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib1_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib2_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib2_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "2"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib2_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib2_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib2_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib3_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib3_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "3-9 (~3)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib3_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib3_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib3_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib4_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib4_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "3-9 (~4)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib4_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib4_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib4_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib5_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib5_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "3-9 (~5)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib5_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib5_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib5_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib6_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib6_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "3-9 (~6)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib6_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib6_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib6_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib7_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib7_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "3-9 (~7)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib7_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib7_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib7_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib8_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib8_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "3-9 (~8)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib8_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib8_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib8_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib9_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib9_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "3-9 (~9)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib9_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib9_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib9_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib10_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib10_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "10"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib10_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib10_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib10_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib11_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib11_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "11"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib11_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib11_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib11_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib12_L_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib12_L_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "12"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib12_R_head_neck_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Checkbox, {
        name: "Rib12_R_sternal_end_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Rib12_R",
        value: "0"
      })))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "6"
      }, "Left"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "6"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "#")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "#")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "5"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Hand"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "5"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "5"
      }, /*#__PURE__*/React.createElement("input", {
        className: "mc",
        type: "text",
        name: "MC_L_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MC 1"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "5"
      }, /*#__PURE__*/React.createElement("input", {
        className: "mc",
        type: "text",
        name: "MC_R_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC1_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MC 2"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC2_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MC 3"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC3_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MC 4"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC4_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MC 5"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MC5_R",
        value: "0"
      }))))), /*#__PURE__*/React.createElement("div", {
        className: "phalanges"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, "#"))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("th", null, "Prox. hand phalanges"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Phalanx_P_count_hand"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("th", null, "Int. hand phalanges"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Phalanx_I_count_hand"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("th", null, "Dist. hand phalanges"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Phalanx_D_count_hand"
      }))))), /*#__PURE__*/React.createElement("label", null, /*#__PURE__*/React.createElement("div", null, "# (juv.)"), /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Phalanx_juv_count_hand"
      })))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", {
        className: "left",
        colSpan: "6"
      }, "Left"), /*#__PURE__*/React.createElement("th", {
        colSpan: "3"
      }), /*#__PURE__*/React.createElement("th", {
        className: "right",
        colSpan: "6"
      }, "Right")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "#")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "#")))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT_L_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "5"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT_L_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "bone"
      }, "Foot"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT_R_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "5"
      }), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT_R_complete",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "5"
      }, /*#__PURE__*/React.createElement("input", {
        className: "mt",
        type: "text",
        name: "MT_L_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MT 1"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "5"
      }, /*#__PURE__*/React.createElement("input", {
        className: "mt",
        type: "text",
        name: "MT_R_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT1_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MT 2"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT2_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MT 3"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT3_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MT 4"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT4_R",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_L",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_L",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_L",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_L",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_L",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_L",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "MT 5"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_R",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_R",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_R",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_R",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_R",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "MT5_R",
        value: "0"
      }))))), /*#__PURE__*/React.createElement("div", {
        className: "phalanges"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", null, "#"))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("th", null, "Prox. foot phalanges"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Phalanx_P_count_foot"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("th", null, "Int. foot phalanges"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Phalanx_I_count_foot"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("th", null, "Dist. foot phalanges"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Phalanx_D_count_foot"
      }))))), /*#__PURE__*/React.createElement("label", null, /*#__PURE__*/React.createElement("div", null, "# (juv.)"), /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Phalanx_juv_count_foot"
      }))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-row"
      }, /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("table", {
        className: "osteo vertebrae"
      }, /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", {
        className: "sides"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "hspace"
      }), /*#__PURE__*/React.createElement("th", {
        colSpan: "7"
      }, "Centrum (body)"), /*#__PURE__*/React.createElement("th", {
        className: "hspace"
      }), /*#__PURE__*/React.createElement("th", {
        colSpan: "2"
      }), /*#__PURE__*/React.createElement("th", {
        className: "hspace"
      }), /*#__PURE__*/React.createElement("th", {
        colSpan: "7"
      }, "Left arch"), /*#__PURE__*/React.createElement("th", {
        className: "hspace"
      }), /*#__PURE__*/React.createElement("th", {
        colSpan: "7"
      }, "Right arch")), /*#__PURE__*/React.createElement("tr", {
        className: "labels"
      }, /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "hspace"
      }), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "centrum"
      }, /*#__PURE__*/React.createElement("span", null, "#")), /*#__PURE__*/React.createElement("th", {
        className: "centrum"
      }, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", {
        className: "centrum"
      }, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", {
        className: "centrum"
      }, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", {
        className: "centrum"
      }, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", {
        className: "centrum complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", {
        className: "hspace"
      }), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", {
        className: "hspace"
      }), /*#__PURE__*/React.createElement("th", {
        className: "arch complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "#")), /*#__PURE__*/React.createElement("th", null), /*#__PURE__*/React.createElement("th", {
        className: "hspace"
      }), /*#__PURE__*/React.createElement("th", {
        className: "arch complete"
      }, /*#__PURE__*/React.createElement("span", null, "compl.")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, ">75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "50-75%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "25-50%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "<25%")), /*#__PURE__*/React.createElement("th", null, /*#__PURE__*/React.createElement("span", null, "#")), /*#__PURE__*/React.createElement("th", null))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Vertebrae_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "8"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "8"
      }), /*#__PURE__*/React.createElement("td", null), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Vertebrae_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "8"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "8"
      })), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "C1"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "7"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "C_L_arch_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "7"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "C_R_arch_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C1_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "6"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "C_centra_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "C2"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C2_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "C3-6 (~3)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C3_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "C3-6 (~4)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C4_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "C3-6 (~5)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C5_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "C3-6 (~6)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C6_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "C7"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "C7_R_arch",
        value: "0"
      })))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "13"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "13"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "2"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "13"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "13"
      })), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "12"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "T_centra_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T1"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "12"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "T_L_arch_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "12"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "T_R_arch_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T1_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T2-9 (~2)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T2_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T2-9 (~3)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T3_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T2-9 (~4)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T4_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T2-9 (~5)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T5_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T2-9 (~6)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T6_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T2-9 (~7)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T7_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T2-9 (~8)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T8_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T2-9 (~9)"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T9_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T10"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T10_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T11"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T11_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "T12"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "T12_R_arch",
        value: "0"
      })))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "6"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "6"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "2"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "6"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "6"
      })), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "5"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "L_centra_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "L1"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "5"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "L_L_arch_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "5"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "L_R_arch_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L1_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "L2"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L2_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "L3"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L3_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "L4"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L4_R_arch",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "L5"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_L_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_L_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_L_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_L_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_L_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_L_arch",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_R_arch",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_R_arch",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_R_arch",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_R_arch",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_R_arch",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "L5_R_arch",
        value: "0"
      })))), /*#__PURE__*/React.createElement("tbody", null, /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "8"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "8"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "2"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        colSpan: "7"
      }), /*#__PURE__*/React.createElement("td", {
        className: "hspace",
        rowSpan: "7"
      })), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "6"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "S_centra_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Sacrum"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_L_alae",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_L_alae",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_L_alae",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_L_alae",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_L_alae",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "6"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "S_L_ala_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_L_alae",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_R_alae",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_R_alae",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_R_alae",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_R_alae",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_R_alae",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", {
        rowSpan: "6"
      }, /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "S_R_ala_count"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Sacrum_R_alae",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "S1"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_L_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_L_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_L_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_L_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_L_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_L_ala",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_R_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_R_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_R_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_R_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_R_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S1_R_ala",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "S2"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_L_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_L_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_L_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_L_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_L_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_L_ala",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_R_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_R_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_R_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_R_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_R_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S2_R_ala",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "S3"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_L_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_L_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_L_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_L_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_L_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_L_ala",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_R_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_R_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_R_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_R_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_R_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S3_R_ala",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "S4"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_L_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_L_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_L_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_L_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_L_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_L_ala",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_R_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_R_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_R_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_R_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_R_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S4_R_ala",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_centrum",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_centrum",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_centrum",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_centrum",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_centrum",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_centrum",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "S5"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_complete",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_L_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_L_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_L_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_L_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_L_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_L_ala",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_R_ala",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_R_ala",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_R_ala",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_R_ala",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_R_ala",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "S5_R_ala",
        value: "0"
      }))), /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Coccyx_complete",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Coccyx",
        value: "0"
      })), /*#__PURE__*/React.createElement("td", null), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Coccyx",
        value: "3"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Coccyx",
        value: "2b"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Coccyx",
        value: "2a"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Coccyx",
        value: "1"
      })), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Coccyx",
        value: "C"
      })), /*#__PURE__*/React.createElement("td", {
        className: "segment"
      }, "Coccyx"), /*#__PURE__*/React.createElement("td", null, /*#__PURE__*/React.createElement(Radio, {
        name: "Coccyx_complete",
        value: "C"
      })))))), /*#__PURE__*/React.createElement("div", {
        className: "osteo-column"
      }, /*#__PURE__*/React.createElement("div", {
        className: "osteo dental"
      }, /*#__PURE__*/React.createElement("div", {
        className: "permanent"
      }, /*#__PURE__*/React.createElement("h3", null, "Permanent Dentition"), /*#__PURE__*/React.createElement("div", {
        className: "key"
      }, "0=absent; F=frag.; 1-5=wear stage"), permanentDentZeroButton, /*#__PURE__*/React.createElement("fieldset", {
        className: "upper"
      }, /*#__PURE__*/React.createElement("legend", null, "Upper"), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 40,
          top: 219
        }
      }, "RM", /*#__PURE__*/React.createElement("sup", null, "3"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UM3_R",
        type: "text",
        style: {
          left: -29,
          top: -2
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 43,
          top: 194
        }
      }, "RM", /*#__PURE__*/React.createElement("sup", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UM2_R",
        type: "text",
        style: {
          left: -29,
          top: -3
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 49,
          top: 167
        }
      }, "RM", /*#__PURE__*/React.createElement("sup", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UM1_R",
        type: "text",
        style: {
          left: -29,
          top: -9
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 53,
          top: 143
        }
      }, "RP", /*#__PURE__*/React.createElement("sup", null, "4"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UP4_R",
        type: "text",
        style: {
          left: -25,
          top: -11
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 17,
          top: 102
        }
      }, "RP", /*#__PURE__*/React.createElement("sup", null, "3"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UP3_R",
        type: "text",
        style: {
          left: 21,
          top: 12
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 32,
          top: 76
        }
      }, "RC", /*#__PURE__*/React.createElement("sup", null, "X"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UC_R",
        type: "text",
        style: {
          left: 16,
          top: 17
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 55,
          top: 53
        }
      }, "RI", /*#__PURE__*/React.createElement("sup", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UI2_R",
        type: "text",
        style: {
          left: 11,
          top: 18
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 92,
          top: 41
        }
      }, "RI", /*#__PURE__*/React.createElement("sup", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UI1_R",
        type: "text",
        style: {
          left: 0,
          top: 22
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 124,
          top: 41
        }
      }, "LI", /*#__PURE__*/React.createElement("sup", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UI1_L",
        type: "text",
        style: {
          left: -4,
          top: 22
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 160,
          top: 53
        }
      }, "LI", /*#__PURE__*/React.createElement("sup", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UI2_L",
        type: "text",
        style: {
          left: -14,
          top: 18
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 179,
          top: 76
        }
      }, "LC", /*#__PURE__*/React.createElement("sup", null, "X"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UC_L",
        type: "text",
        style: {
          left: -18,
          top: 17
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 195,
          top: 102
        }
      }, "LP", /*#__PURE__*/React.createElement("sup", null, "3"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UP3_L",
        type: "text",
        style: {
          left: -24,
          top: 12
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 156,
          top: 143
        }
      }, "LP", /*#__PURE__*/React.createElement("sup", null, "4"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UP4_L",
        type: "text",
        style: {
          left: 25,
          top: -11
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 157,
          top: 167
        }
      }, "LM", /*#__PURE__*/React.createElement("sup", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UM1_L",
        type: "text",
        style: {
          left: 29,
          top: -9
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 163,
          top: 194
        }
      }, "LM", /*#__PURE__*/React.createElement("sup", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UM2_L",
        type: "text",
        style: {
          left: 29,
          top: -3
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 166,
          top: 219
        }
      }, "LM", /*#__PURE__*/React.createElement("sup", null, "3"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_UM3_L",
        type: "text",
        style: {
          left: 29,
          top: -2
        }
      }))), /*#__PURE__*/React.createElement("fieldset", {
        className: "lower"
      }, /*#__PURE__*/React.createElement("legend", null, "Lower"), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 50,
          top: 284
        }
      }, "RM", /*#__PURE__*/React.createElement("sub", null, "3"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LM3_R",
        type: "text",
        style: {
          left: -30,
          top: 0
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 53,
          top: 314
        }
      }, "RM", /*#__PURE__*/React.createElement("sub", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LM2_R",
        type: "text",
        style: {
          left: -30,
          top: 2
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 62,
          top: 341
        }
      }, "RM", /*#__PURE__*/React.createElement("sub", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LM1_R",
        type: "text",
        style: {
          left: -29,
          top: 7
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 64,
          top: 367
        }
      }, "RP", /*#__PURE__*/React.createElement("sub", null, "4"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LP4_R",
        type: "text",
        style: {
          left: -21,
          top: 9
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 30,
          top: 412
        }
      }, "RP", /*#__PURE__*/React.createElement("sub", null, "3"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LP3_R",
        type: "text",
        style: {
          left: 20,
          top: -14
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 46,
          top: 434
        }
      }, "RC", /*#__PURE__*/React.createElement("sub", null, "X"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LC_R",
        type: "text",
        style: {
          left: 15,
          top: -18
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 77,
          top: 446
        }
      }, "I", /*#__PURE__*/React.createElement("sub", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LI2_R",
        type: "text",
        style: {
          left: 5,
          top: -18
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 100,
          top: 453
        }
      }, "I", /*#__PURE__*/React.createElement("sub", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LI1_R",
        type: "text",
        style: {
          left: -1,
          top: -20
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 122,
          top: 452
        }
      }, "I", /*#__PURE__*/React.createElement("sub", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LI1_L",
        type: "text",
        style: {
          left: -5,
          top: -20
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 143,
          top: 445
        }
      }, "I", /*#__PURE__*/React.createElement("sub", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LI2_L",
        type: "text",
        style: {
          left: -9,
          top: -18
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 162,
          top: 433
        }
      }, "LC", /*#__PURE__*/React.createElement("sub", null, "X"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LC_L",
        type: "text",
        style: {
          left: -17,
          top: -18
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 178,
          top: 412
        }
      }, "LP", /*#__PURE__*/React.createElement("sub", null, "3"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LP3_L",
        type: "text",
        style: {
          left: -21,
          top: -15
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 142,
          top: 367
        }
      }, "LP", /*#__PURE__*/React.createElement("sub", null, "4"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LP4_L",
        type: "text",
        style: {
          left: 23,
          top: 8
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 143,
          top: 341
        }
      }, "LM", /*#__PURE__*/React.createElement("sub", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LM1_L",
        type: "text",
        style: {
          left: 29,
          top: 7
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 151,
          top: 314
        }
      }, "LM", /*#__PURE__*/React.createElement("sub", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LM2_L",
        type: "text",
        style: {
          left: 30,
          top: 2
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 155,
          top: 284
        }
      }, "LM", /*#__PURE__*/React.createElement("sub", null, "3"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_LM3_L",
        type: "text",
        style: {
          left: 29,
          top: 0
        }
      })))), /*#__PURE__*/React.createElement("div", {
        className: "deciduous"
      }, /*#__PURE__*/React.createElement("h3", null, "Deciduous Dentition"), /*#__PURE__*/React.createElement("div", {
        className: "key"
      }, "0=absent; F=frag.; 1-5=wear stage"), deciduousDentZeroButton, /*#__PURE__*/React.createElement("fieldset", {
        className: "upper"
      }, /*#__PURE__*/React.createElement("legend", null, "Upper"), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 34,
          top: 143
        }
      }, "Rdm", /*#__PURE__*/React.createElement("sup", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udm2_R",
        type: "text",
        style: {
          left: -30,
          top: -3
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 39,
          top: 115
        }
      }, "Rdm", /*#__PURE__*/React.createElement("sup", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udm1_R",
        type: "text",
        style: {
          left: -26,
          top: -8
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 11,
          top: 71
        }
      }, "Rdc", /*#__PURE__*/React.createElement("sup", null, "x"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udc_R",
        type: "text",
        style: {
          left: 21,
          top: 13
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 39,
          top: 51
        }
      }, "Rdi", /*#__PURE__*/React.createElement("sup", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udi2_R",
        type: "text",
        style: {
          left: 7,
          top: 16
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 68,
          top: 44
        }
      }, "Rdi", /*#__PURE__*/React.createElement("sup", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udi1_R",
        type: "text",
        style: {
          left: -1,
          top: 17
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 94,
          top: 44
        }
      }, "Ldi", /*#__PURE__*/React.createElement("sup", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udi1_L",
        type: "text",
        style: {
          left: -4,
          top: 17
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 121,
          top: 51
        }
      }, "Ldi", /*#__PURE__*/React.createElement("sup", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udi2_L",
        type: "text",
        style: {
          left: -11,
          top: 16
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 147,
          top: 73
        }
      }, "Ldc", /*#__PURE__*/React.createElement("sup", null, "x"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udc_L",
        type: "text",
        style: {
          left: -24,
          top: 11
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 111,
          top: 115
        }
      }, "Ldm", /*#__PURE__*/React.createElement("sup", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udm1_L",
        type: "text",
        style: {
          left: 27,
          top: -8
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 116,
          top: 143
        }
      }, "Ldm", /*#__PURE__*/React.createElement("sup", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Udm2_L",
        type: "text",
        style: {
          left: 31,
          top: -3
        }
      }))), /*#__PURE__*/React.createElement("fieldset", {
        className: "lower"
      }, /*#__PURE__*/React.createElement("legend", null, "Lower"), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 36,
          top: 198
        }
      }, "Rdm", /*#__PURE__*/React.createElement("sub", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldm2_R",
        type: "text",
        style: {
          left: -29,
          top: 1
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 47,
          top: 228
        }
      }, "Rdm", /*#__PURE__*/React.createElement("sub", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldm1_R",
        type: "text",
        style: {
          left: -28,
          top: 4
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 27,
          top: 272
        }
      }, "dc", /*#__PURE__*/React.createElement("sub", null, "x"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldc_R",
        type: "text",
        style: {
          left: 11,
          top: -17
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 50,
          top: 286
        }
      }, "di", /*#__PURE__*/React.createElement("sub", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldi2_R",
        type: "text",
        style: {
          left: 4,
          top: -17
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 72,
          top: 290
        }
      }, "di", /*#__PURE__*/React.createElement("sub", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldi1_R",
        type: "text",
        style: {
          left: 0,
          top: -18
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 93,
          top: 290
        }
      }, "di", /*#__PURE__*/React.createElement("sub", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldi1_L",
        type: "text",
        style: {
          left: -3,
          top: -18
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 115,
          top: 285
        }
      }, "di", /*#__PURE__*/React.createElement("sub", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldi2_L",
        type: "text",
        style: {
          left: -7,
          top: -16
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 136,
          top: 272
        }
      }, "dc", /*#__PURE__*/React.createElement("sub", null, "x"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldc_L",
        type: "text",
        style: {
          left: -15,
          top: -17
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 102,
          top: 228
        }
      }, "Ldm", /*#__PURE__*/React.createElement("sub", null, "1"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldm1_L",
        type: "text",
        style: {
          left: 28,
          top: 4
        }
      })), /*#__PURE__*/React.createElement("label", {
        style: {
          left: 113,
          top: 198
        }
      }, "Ldm", /*#__PURE__*/React.createElement("sub", null, "2"), /*#__PURE__*/React.createElement("input", {
        name: "Teeth_decid_Ldm2_L",
        type: "text",
        style: {
          left: 30,
          top: 0
        }
      }))), /*#__PURE__*/React.createElement("div", {
        className: "immVertFrags"
      }, /*#__PURE__*/React.createElement("h3", null, "Imm. Vert. frags"), "Count", ' ', /*#__PURE__*/React.createElement("input", {
        type: "text",
        name: "Teeth_immVertFragsCount"
      })))))));
      /* eslint-enable
         jsx-a11y/control-has-associated-label,
         jsx-a11y/label-has-associated-control */
    }
    renderForm(component) {
      if (!component) {
        return component;
      }
      const {
        readOnly,
        value: data
      } = this.props;
      const {
        type,
        props
      } = component;
      if (!props) {
        return component;
      }
      const {
        name,
        value,
        children
      } = props;
      const overrideProps = {};
      if (type === Radio || type === Checkbox) {
        overrideProps.checked = data.get(name) === value;
        overrideProps.disabled = readOnly;
        overrideProps.onChange = this.handleChange;
        this.radioOrCheckboxFieldNames[name] = true;
      } else if (type === 'input') {
        overrideProps.disabled = readOnly;
        overrideProps.value = data.get(name) || '';
        overrideProps.onChange = this.handleChange;
        this.textFieldNames[name] = true;
      }
      return React.cloneElement(component, overrideProps, React.Children.map(children, child => this.renderForm(child)));
    }
    render() {
      const {
        value
      } = this.props;
      return value ? this.renderForm(this.renderTemplate()) : null;
    }
  }
  OsteoInventoryInput.propTypes = propTypes;
  return OsteoInventoryInput;
};
exports.default = _default;